==> react-source-render-3.0.0-0.tgz: package/dist-src/useRenderElement.js <==
import _objectWithoutProperties from "@babel/runtime-corejs2/helpers/objectWithoutProperties";
import * as React from "react";
import { renderToStaticMarkup } from "react-dom/server";
import { useCreateComponentFromSource } from "./useCreateComponentFromSource.js";

var useResolveHandler = function useResolveHandler(resolver, context) {
  var latestResolver = React.useRef(resolver);
  var latestContext = React.useRef(context);
  latestResolver.current = resolver;
  latestContext.current = context;
  return React.useCallback(function (importName) {
    return latestResolver.current(importName, latestContext.current);
  }, []);
};

var useRenderElement = function useRenderElement(options) {
  var babelConfig = options.babelConfig,
      source = options.source,
      renderHtml = options.renderHtml,
      resolver = options.resolver,
      resolverContext = options.resolverContext,
      rest = _objectWithoutProperties(options, ["babelConfig", "source", "renderHtml", "resolver", "resolverContext"]);

  var handleResolve = useResolveHandler(resolver, resolverContext);
  var latestElement = React.useRef(null);
  var latestMarkup = React.useRef("");

  try {
    var component = useCreateComponentFromSource(babelConfig, source, handleResolve);
    latestElement.current = React.createElement(component, rest);
    latestMarkup.current = renderHtml ? renderToStaticMarkup(latestElement.current) : '';
    return {
      element: latestElement.current,
      markup: latestMarkup.current,
      error: null
    };
  } catch (error) {
    return {
      element: latestElement.current,
      markup: latestMarkup.current,
      error: error
    };
  }
};

export default useRenderElement;

==> react-source-render-3.0.0-5.tgz: package/dist-src/useRenderElement.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import * as React from "react";
import { renderToStaticMarkup } from "react-dom/server";
import { useCreateComponentFromSource } from "./useCreateComponentFromSource.js";

var useResolveHandler = function useResolveHandler(resolver, context) {
  var latestResolver = React.useRef(resolver);
  var latestContext = React.useRef(context);
  latestResolver.current = resolver;
  latestContext.current = context;
  return React.useCallback(function (importName) {
    return latestResolver.current(importName, latestContext.current);
  }, []);
};

var useRenderElement = function useRenderElement(options) {
  var babelConfig = options.babelConfig,
      source = options.source,
      renderHtml = options.renderHtml,
      resolver = options.resolver,
      resolverContext = options.resolverContext,
      unstable_hot = options.unstable_hot,
      wrap = options.wrap,
      rest = _objectWithoutProperties(options, ["babelConfig", "source", "renderHtml", "resolver", "resolverContext", "unstable_hot", "wrap"]);

  var handleResolve = useResolveHandler(resolver, resolverContext);
  var latestElement = React.useRef(null);
  var latestMarkup = React.useRef("");

  try {
    var component = useCreateComponentFromSource(babelConfig, unstable_hot, source, handleResolve);
    latestElement.current = React.createElement(component, rest);
    latestMarkup.current = renderHtml ? renderToStaticMarkup(wrap(latestElement.current)) : '';
    return {
      element: latestElement.current,
      markup: latestMarkup.current,
      error: null
    };
  } catch (error) {
    return {
      element: latestElement.current,
      markup: latestMarkup.current,
      error: error
    };
  }
};

export default useRenderElement;
